==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPolyData.java <==
// java wrapper for vtkPolyData object
//

package vtk;
import vtk.*;

public class vtkPolyData extends vtkPointSet
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native void CopyStructure_3(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_3(id0); }

  private native int GetNumberOfCells_4();
  public int GetNumberOfCells()
    { return GetNumberOfCells_4(); }

  private native long GetCell_5(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_5(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_6(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_6(id0,id1); }

  private native int GetCellType_7(int id0);
  public int GetCellType(int id0)
    { return GetCellType_7(id0); }

  private native void GetCellBounds_8(int id0,double id1[]);
  public void GetCellBounds(int id0,double id1[])
    { GetCellBounds_8(id0,id1); }

  private native void GetCellNeighbors_9(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_9(id0,id1,id2); }

  private native void CopyCells_10(vtkPolyData id0,vtkIdList id1,vtkPointLocator id2);
  public void CopyCells(vtkPolyData id0,vtkIdList id1,vtkPointLocator id2)
    { CopyCells_10(id0,id1,id2); }

  private native void GetCellPoints_11(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_11(id0,id1); }

  private native void GetPointCells_12(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_12(id0,id1); }

  private native void ComputeBounds_13();
  public void ComputeBounds()
    { ComputeBounds_13(); }

  private native void Squeeze_14();
  public void Squeeze()
    { Squeeze_14(); }

  private native int GetMaxCellSize_15();
  public int GetMaxCellSize()
    { return GetMaxCellSize_15(); }

  private native void SetVerts_16(vtkCellArray id0);
  public void SetVerts(vtkCellArray id0)
    { SetVerts_16(id0); }

  private native long GetVerts_17();
  public vtkCellArray GetVerts() {
    long temp = GetVerts_17();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLines_18(vtkCellArray id0);
  public void SetLines(vtkCellArray id0)
    { SetLines_18(id0); }

  private native long GetLines_19();
  public vtkCellArray GetLines() {
    long temp = GetLines_19();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPolys_20(vtkCellArray id0);
  public void SetPolys(vtkCellArray id0)
    { SetPolys_20(id0); }

  private native long GetPolys_21();
  public vtkCellArray GetPolys() {
    long temp = GetPolys_21();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetStrips_22(vtkCellArray id0);
  public void SetStrips(vtkCellArray id0)
    { SetStrips_22(id0); }

  private native long GetStrips_23();
  public vtkCellArray GetStrips() {
    long temp = GetStrips_23();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfVerts_24();
  public int GetNumberOfVerts()
    { return GetNumberOfVerts_24(); }

  private native int GetNumberOfLines_25();
  public int GetNumberOfLines()
    { return GetNumberOfLines_25(); }

  private native int GetNumberOfPolys_26();
  public int GetNumberOfPolys()
    { return GetNumberOfPolys_26(); }

  private native int GetNumberOfStrips_27();
  public int GetNumberOfStrips()
    { return GetNumberOfStrips_27(); }

  private native void Allocate_28(int id0,int id1);
  public void Allocate(int id0,int id1)
    { Allocate_28(id0,id1); }

  private native void Allocate_29(vtkPolyData id0,int id1,int id2);
  public void Allocate(vtkPolyData id0,int id1,int id2)
    { Allocate_29(id0,id1,id2); }

  private native int InsertNextCell_30(int id0,vtkIdList id1);
  public int InsertNextCell(int id0,vtkIdList id1)
    { return InsertNextCell_30(id0,id1); }

  private native void Reset_31();
  public void Reset()
    { Reset_31(); }

  private native void BuildCells_32();
  public void BuildCells()
    { BuildCells_32(); }

  private native boolean NeedToBuildCells_33();
  public boolean NeedToBuildCells()
    { return NeedToBuildCells_33(); }

  private native void BuildLinks_34(int id0);
  public void BuildLinks(int id0)
    { BuildLinks_34(id0); }

  private native void DeleteCells_35();
  public void DeleteCells()
    { DeleteCells_35(); }

  private native void DeleteLinks_36();
  public void DeleteLinks()
    { DeleteLinks_36(); }

  private native void GetCellEdgeNeighbors_37(int id0,int id1,int id2,vtkIdList id3);
  public void GetCellEdgeNeighbors(int id0,int id1,int id2,vtkIdList id3)
    { GetCellEdgeNeighbors_37(id0,id1,id2,id3); }

  private native int IsTriangle_38(int id0,int id1,int id2);
  public int IsTriangle(int id0,int id1,int id2)
    { return IsTriangle_38(id0,id1,id2); }

  private native int IsEdge_39(int id0,int id1);
  public int IsEdge(int id0,int id1)
    { return IsEdge_39(id0,id1); }

  private native int IsPointUsedByCell_40(int id0,int id1);
  public int IsPointUsedByCell(int id0,int id1)
    { return IsPointUsedByCell_40(id0,id1); }

  private native void ReplaceCellPoint_41(int id0,int id1,int id2);
  public void ReplaceCellPoint(int id0,int id1,int id2)
    { ReplaceCellPoint_41(id0,id1,id2); }

  private native void ReverseCell_42(int id0);
  public void ReverseCell(int id0)
    { ReverseCell_42(id0); }

  private native void DeletePoint_43(int id0);
  public void DeletePoint(int id0)
    { DeletePoint_43(id0); }

  private native void DeleteCell_44(int id0);
  public void DeleteCell(int id0)
    { DeleteCell_44(id0); }

  private native void RemoveDeletedCells_45();
  public void RemoveDeletedCells()
    { RemoveDeletedCells_45(); }

  private native int InsertNextLinkedPoint_46(int id0);
  public int InsertNextLinkedPoint(int id0)
    { return InsertNextLinkedPoint_46(id0); }

  private native int InsertNextLinkedPoint_47(double id0[],int id1);
  public int InsertNextLinkedPoint(double id0[],int id1)
    { return InsertNextLinkedPoint_47(id0,id1); }

  private native void RemoveCellReference_48(int id0);
  public void RemoveCellReference(int id0)
    { RemoveCellReference_48(id0); }

  private native void AddCellReference_49(int id0);
  public void AddCellReference(int id0)
    { AddCellReference_49(id0); }

  private native void RemoveReferenceToCell_50(int id0,int id1);
  public void RemoveReferenceToCell(int id0,int id1)
    { RemoveReferenceToCell_50(id0,id1); }

  private native void AddReferenceToCell_51(int id0,int id1);
  public void AddReferenceToCell(int id0,int id1)
    { AddReferenceToCell_51(id0,id1); }

  private native void ResizeCellList_52(int id0,int id1);
  public void ResizeCellList(int id0,int id1)
    { ResizeCellList_52(id0,id1); }

  private native void Initialize_53();
  public void Initialize()
    { Initialize_53(); }

  private native int GetPiece_54();
  public int GetPiece()
    { return GetPiece_54(); }

  private native int GetNumberOfPieces_55();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_55(); }

  private native int GetGhostLevel_56();
  public int GetGhostLevel()
    { return GetGhostLevel_56(); }

  private native int GetActualMemorySize_57();
  public int GetActualMemorySize()
    { return GetActualMemorySize_57(); }

  private native void ShallowCopy_58(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_58(id0); }

  private native void DeepCopy_59(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_59(id0); }

  private native void RemoveGhostCells_60();
  public void RemoveGhostCells()
    { RemoveGhostCells_60(); }

  private native long GetData_61(vtkInformation id0);
  public vtkPolyData GetData(vtkInformation id0) {
    long temp = GetData_61(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_62(vtkInformationVector id0,int id1);
  public vtkPolyData GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_62(id0,id1);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetScalarFieldCriticalIndex_63(int id0,vtkDataArray id1);
  public int GetScalarFieldCriticalIndex(int id0,vtkDataArray id1)
    { return GetScalarFieldCriticalIndex_63(id0,id1); }

  private native int GetScalarFieldCriticalIndex_64(int id0,int id1);
  public int GetScalarFieldCriticalIndex(int id0,int id1)
    { return GetScalarFieldCriticalIndex_64(id0,id1); }

  private native int GetScalarFieldCriticalIndex_65(int id0,String id1);
  public int GetScalarFieldCriticalIndex(int id0,String id1)
    { return GetScalarFieldCriticalIndex_65(id0,id1); }

  public vtkPolyData() { super(); }

  public vtkPolyData(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-5-armv7h.pkg.tar.xz: vtk/vtkPolyData.java <==
// java wrapper for vtkPolyData object
//

package vtk;
import vtk.*;

public class vtkPolyData extends vtkPointSet
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native void CopyStructure_3(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_3(id0); }

  private native int GetNumberOfCells_4();
  public int GetNumberOfCells()
    { return GetNumberOfCells_4(); }

  private native long GetCell_5(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_5(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_6(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_6(id0,id1); }

  private native int GetCellType_7(int id0);
  public int GetCellType(int id0)
    { return GetCellType_7(id0); }

  private native void GetCellBounds_8(int id0,double id1[]);
  public void GetCellBounds(int id0,double id1[])
    { GetCellBounds_8(id0,id1); }

  private native void GetCellNeighbors_9(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_9(id0,id1,id2); }

  private native void CopyCells_10(vtkPolyData id0,vtkIdList id1,vtkPointLocator id2);
  public void CopyCells(vtkPolyData id0,vtkIdList id1,vtkPointLocator id2)
    { CopyCells_10(id0,id1,id2); }

  private native void GetCellPoints_11(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_11(id0,id1); }

  private native void GetPointCells_12(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_12(id0,id1); }

  private native void ComputeBounds_13();
  public void ComputeBounds()
    { ComputeBounds_13(); }

  private native void Squeeze_14();
  public void Squeeze()
    { Squeeze_14(); }

  private native int GetMaxCellSize_15();
  public int GetMaxCellSize()
    { return GetMaxCellSize_15(); }

  private native void SetVerts_16(vtkCellArray id0);
  public void SetVerts(vtkCellArray id0)
    { SetVerts_16(id0); }

  private native long GetVerts_17();
  public vtkCellArray GetVerts() {
    long temp = GetVerts_17();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLines_18(vtkCellArray id0);
  public void SetLines(vtkCellArray id0)
    { SetLines_18(id0); }

  private native long GetLines_19();
  public vtkCellArray GetLines() {
    long temp = GetLines_19();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPolys_20(vtkCellArray id0);
  public void SetPolys(vtkCellArray id0)
    { SetPolys_20(id0); }

  private native long GetPolys_21();
  public vtkCellArray GetPolys() {
    long temp = GetPolys_21();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetStrips_22(vtkCellArray id0);
  public void SetStrips(vtkCellArray id0)
    { SetStrips_22(id0); }

  private native long GetStrips_23();
  public vtkCellArray GetStrips() {
    long temp = GetStrips_23();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfVerts_24();
  public int GetNumberOfVerts()
    { return GetNumberOfVerts_24(); }

  private native int GetNumberOfLines_25();
  public int GetNumberOfLines()
    { return GetNumberOfLines_25(); }

  private native int GetNumberOfPolys_26();
  public int GetNumberOfPolys()
    { return GetNumberOfPolys_26(); }

  private native int GetNumberOfStrips_27();
  public int GetNumberOfStrips()
    { return GetNumberOfStrips_27(); }

  private native void Allocate_28(int id0,int id1);
  public void Allocate(int id0,int id1)
    { Allocate_28(id0,id1); }

  private native void Allocate_29(vtkPolyData id0,int id1,int id2);
  public void Allocate(vtkPolyData id0,int id1,int id2)
    { Allocate_29(id0,id1,id2); }

  private native int InsertNextCell_30(int id0,vtkIdList id1);
  public int InsertNextCell(int id0,vtkIdList id1)
    { return InsertNextCell_30(id0,id1); }

  private native void Reset_31();
  public void Reset()
    { Reset_31(); }

  private native void BuildCells_32();
  public void BuildCells()
    { BuildCells_32(); }

  private native boolean NeedToBuildCells_33();
  public boolean NeedToBuildCells()
    { return NeedToBuildCells_33(); }

  private native void BuildLinks_34(int id0);
  public void BuildLinks(int id0)
    { BuildLinks_34(id0); }

  private native void DeleteCells_35();
  public void DeleteCells()
    { DeleteCells_35(); }

  private native void DeleteLinks_36();
  public void DeleteLinks()
    { DeleteLinks_36(); }

  private native void GetCellEdgeNeighbors_37(int id0,int id1,int id2,vtkIdList id3);
  public void GetCellEdgeNeighbors(int id0,int id1,int id2,vtkIdList id3)
    { GetCellEdgeNeighbors_37(id0,id1,id2,id3); }

  private native int IsTriangle_38(int id0,int id1,int id2);
  public int IsTriangle(int id0,int id1,int id2)
    { return IsTriangle_38(id0,id1,id2); }

  private native int IsEdge_39(int id0,int id1);
  public int IsEdge(int id0,int id1)
    { return IsEdge_39(id0,id1); }

  private native int IsPointUsedByCell_40(int id0,int id1);
  public int IsPointUsedByCell(int id0,int id1)
    { return IsPointUsedByCell_40(id0,id1); }

  private native void ReplaceCellPoint_41(int id0,int id1,int id2);
  public void ReplaceCellPoint(int id0,int id1,int id2)
    { ReplaceCellPoint_41(id0,id1,id2); }

  private native void ReverseCell_42(int id0);
  public void ReverseCell(int id0)
    { ReverseCell_42(id0); }

  private native void DeletePoint_43(int id0);
  public void DeletePoint(int id0)
    { DeletePoint_43(id0); }

  private native void DeleteCell_44(int id0);
  public void DeleteCell(int id0)
    { DeleteCell_44(id0); }

  private native void RemoveDeletedCells_45();
  public void RemoveDeletedCells()
    { RemoveDeletedCells_45(); }

  private native int InsertNextLinkedPoint_46(int id0);
  public int InsertNextLinkedPoint(int id0)
    { return InsertNextLinkedPoint_46(id0); }

  private native int InsertNextLinkedPoint_47(double id0[],int id1);
  public int InsertNextLinkedPoint(double id0[],int id1)
    { return InsertNextLinkedPoint_47(id0,id1); }

  private native void RemoveCellReference_48(int id0);
  public void RemoveCellReference(int id0)
    { RemoveCellReference_48(id0); }

  private native void AddCellReference_49(int id0);
  public void AddCellReference(int id0)
    { AddCellReference_49(id0); }

  private native void RemoveReferenceToCell_50(int id0,int id1);
  public void RemoveReferenceToCell(int id0,int id1)
    { RemoveReferenceToCell_50(id0,id1); }

  private native void AddReferenceToCell_51(int id0,int id1);
  public void AddReferenceToCell(int id0,int id1)
    { AddReferenceToCell_51(id0,id1); }

  private native void ResizeCellList_52(int id0,int id1);
  public void ResizeCellList(int id0,int id1)
    { ResizeCellList_52(id0,id1); }

  private native void Initialize_53();
  public void Initialize()
    { Initialize_53(); }

  private native int GetPiece_54();
  public int GetPiece()
    { return GetPiece_54(); }

  private native int GetNumberOfPieces_55();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_55(); }

  private native int GetGhostLevel_56();
  public int GetGhostLevel()
    { return GetGhostLevel_56(); }

  private native int GetActualMemorySize_57();
  public int GetActualMemorySize()
    { return GetActualMemorySize_57(); }

  private native void ShallowCopy_58(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_58(id0); }

  private native void DeepCopy_59(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_59(id0); }

  private native void RemoveGhostCells_60();
  public void RemoveGhostCells()
    { RemoveGhostCells_60(); }

  private native long GetData_61(vtkInformation id0);
  public vtkPolyData GetData(vtkInformation id0) {
    long temp = GetData_61(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_62(vtkInformationVector id0,int id1);
  public vtkPolyData GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_62(id0,id1);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetScalarFieldCriticalIndex_63(int id0,vtkDataArray id1);
  public int GetScalarFieldCriticalIndex(int id0,vtkDataArray id1)
    { return GetScalarFieldCriticalIndex_63(id0,id1); }

  private native int GetScalarFieldCriticalIndex_64(int id0,int id1);
  public int GetScalarFieldCriticalIndex(int id0,int id1)
    { return GetScalarFieldCriticalIndex_64(id0,id1); }

  private native int GetScalarFieldCriticalIndex_65(int id0,String id1);
  public int GetScalarFieldCriticalIndex(int id0,String id1)
    { return GetScalarFieldCriticalIndex_65(id0,id1); }

  private native int GetMeshMTime_66();
  public int GetMeshMTime()
    { return GetMeshMTime_66(); }

  private native int GetMTime_67();
  public int GetMTime()
    { return GetMTime_67(); }

  private native long GetCell_68(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_68(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPolyData() { super(); }

  public vtkPolyData(long id) { super(id); }
  public native long   VTKInit();

}
